==> haskell-monoid-subclasses-0.4.4-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monoid-subclasses.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monoid-subclasses
version: 0.4.4
id: monoid-subclasses-0.4.4-C1b20V6LixEyYdGkPAUzj
key: monoid-subclasses-0.4.4-C1b20V6LixEyYdGkPAUzj
license: BSD3
copyright: (c) 2013-2017 Mario Blažević
maintainer: Mario Blažević <blamario@protonmail.com>
homepage: https://github.com/blamario/monoid-subclasses/
synopsis: Subclasses of Monoid
description:
    A hierarchy of subclasses of '\''Monoid'\'' together with their instances for all data structures from base, containers, and
    text packages.
category: Data, Algebra, Text
author: Mario Blažević
exposed: True
indefinite: False
exposed-modules:
    Data.Monoid.Cancellative Data.Monoid.Factorial
    Data.Monoid.Instances.ByteString.UTF8 Data.Monoid.Instances.Concat
    Data.Monoid.Instances.Measured Data.Monoid.Instances.Positioned
    Data.Monoid.Instances.Stateful Data.Monoid.Null Data.Monoid.Textual
abi: c1c0e93f107237ce6a53ec64b3748af5
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/monoid-subclasses-0.4.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/monoid-subclasses-0.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/monoid-subclasses-0.4.4
hs-libraries: HSmonoid-subclasses-0.4.4-C1b20V6LixEyYdGkPAUzj
depends:
    base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    primes-0.2.1.0-4yl4879BvB2BN6PZhDdStZ
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
             primes-0.2.1.0-4yl4879BvB2BN6PZhDdStZ=221b447e47b71db4fb73d5e98b6aefc9
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=d8375a46a4155c3f449ce3d319b3dbaa
haddock-interfaces: /usr/share/doc/haskell-monoid-subclasses/html/monoid-subclasses.haddock
haddock-html: /usr/share/doc/haskell-monoid-subclasses/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monoid-subclasses-0.4.4-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monoid-subclasses.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monoid-subclasses
version: 0.4.4
id: monoid-subclasses-0.4.4-8t8CkOfpl83Fs1yjOtHpaD
key: monoid-subclasses-0.4.4-8t8CkOfpl83Fs1yjOtHpaD
license: BSD3
copyright: (c) 2013-2017 Mario Blažević
maintainer: Mario Blažević <blamario@protonmail.com>
homepage: https://github.com/blamario/monoid-subclasses/
synopsis: Subclasses of Monoid
description:
    A hierarchy of subclasses of '\''Monoid'\'' together with their instances for all data structures from base, containers, and
    text packages.
category: Data, Algebra, Text
author: Mario Blažević
exposed: True
indefinite: False
exposed-modules:
    Data.Monoid.Cancellative Data.Monoid.Factorial
    Data.Monoid.Instances.ByteString.UTF8 Data.Monoid.Instances.Concat
    Data.Monoid.Instances.Measured Data.Monoid.Instances.Positioned
    Data.Monoid.Instances.Stateful Data.Monoid.Null Data.Monoid.Textual
abi: 5a0787a0c8912c45aac074b9456ce784
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/monoid-subclasses-0.4.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/monoid-subclasses-0.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/monoid-subclasses-0.4.4
hs-libraries: HSmonoid-subclasses-0.4.4-8t8CkOfpl83Fs1yjOtHpaD
depends:
    base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    primes-0.2.1.0-4yl4879BvB2BN6PZhDdStZ
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             primes-0.2.1.0-4yl4879BvB2BN6PZhDdStZ=221b447e47b71db4fb73d5e98b6aefc9
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=d8375a46a4155c3f449ce3d319b3dbaa
haddock-interfaces: /usr/share/doc/haskell-monoid-subclasses/html/monoid-subclasses.haddock
haddock-html: /usr/share/doc/haskell-monoid-subclasses/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
